==> haskell-pipes-http-1.0.5-137-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes-http
version: 1.0.5
id: pipes-http-1.0.5-J8XNp7BjBba8rdX3FMLpic
key: pipes-http-1.0.5-J8XNp7BjBba8rdX3FMLpic
license: BSD-3-Clause
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library
category: Pipes, Web
abi: 8ef2ae9d5255a413404092288713178c
exposed: True
exposed-modules:
    Pipes.HTTP
import-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-http-1.0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-http-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/pipes-http-1.0.5
hs-libraries: HSpipes-http-1.0.5-J8XNp7BjBba8rdX3FMLpic
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    pipes-4.3.9-4bTJ03JeDyCC2Ag0z5iPx3
    http-client-0.5.13-oP0CuDy48eCryfgf9zAeZ
    http-client-tls-0.3.5.3-87ITordiFeaJxpRGoXUThe
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             pipes-4.3.9-4bTJ03JeDyCC2Ag0z5iPx3=161898cb71b57aa36887f8a9809c7904
             http-client-0.5.13-oP0CuDy48eCryfgf9zAeZ=dd5944a929261e121fef45baf41c85c5
             http-client-tls-0.3.5.3-87ITordiFeaJxpRGoXUThe=9d0acec7e2888a2f6d8681c2ef67bb98
haddock-interfaces: /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html: /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-http-1.0.5-145-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes-http
version: 1.0.5
id: pipes-http-1.0.5-5A8e9a7ohau6nNiagPR8TK
key: pipes-http-1.0.5-5A8e9a7ohau6nNiagPR8TK
license: BSD-3-Clause
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library
category: Pipes, Web
abi: b546f2d442e36f0b1bbf112aeaef9638
exposed: True
exposed-modules:
    Pipes.HTTP
import-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-http-1.0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-http-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/pipes-http-1.0.5
hs-libraries: HSpipes-http-1.0.5-5A8e9a7ohau6nNiagPR8TK
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    pipes-4.3.9-4bTJ03JeDyCC2Ag0z5iPx3
    http-client-0.5.13.1-E2oTnwSZQmdIh914s8ng5x
    http-client-tls-0.3.5.3-1zpUVPwvh5wHxc5Fk2W0Kx
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             pipes-4.3.9-4bTJ03JeDyCC2Ag0z5iPx3=161898cb71b57aa36887f8a9809c7904
             http-client-0.5.13.1-E2oTnwSZQmdIh914s8ng5x=7bfdf5a067b9b51eacef98e312bdcb38
             http-client-tls-0.3.5.3-1zpUVPwvh5wHxc5Fk2W0Kx=c707f91820faa43557a62b2504200a19
haddock-interfaces: /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html: /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
